@@ -91,15 +91,18 @@ class Client:
             return [self._cases[x] for x in self._cases if x in cases]
         return self._cases.values()
 
-    def _post(self, path: str, body):
+    def _post(self, path: str, body, headers: Dict[str, str] = {}):
         response = self._transport.request(
             method="POST",
             path=path,
             body=body,
             content_type="application/octet-stream",
+            extra_headers=headers,
         )
         if response.status == 204:
             return
+        if response.status == 200:
+            return response.data.decode("utf-8")
         reason = ""
         if response.status == 400:
             error = response.data.decode("utf-8")
@@ -107,7 +110,7 @@ class Client:
                 reason = " This version is already submitted and sealed."
             if "team not found" in error:
                 reason = " This team does not exist."
-        raise ToucaError("post_failed", reason)
+        raise ToucaError("transport_post", reason)
 
     def configure(self, **kwargs) -> bool:
         """
@@ -283,8 +286,10 @@ class Client:
         :raises ToucaError:
             when called with the name of a test case that was never declared
         """
+        if not self._configured:
+            return
         if name not in self._cases:
-            raise ToucaError("testcase_forget", name)
+            raise ToucaError("capture_forget", name)
         del self._cases[name]
 
     @casemethod
@@ -397,11 +402,14 @@ class Client:
             with the Touca server.
         """
         if not self._configured or self._options.get("offline"):
-            raise ToucaError("client_not_configured")
+            raise ToucaError("capture_not_configured")
         content = serialize_messages(
             [item.serialize() for item in self._cases.values()]
         )
-        self._post("/client/submit", content)
+        headers = {
+            "X-Touca-Submission-Mode": self._options.get("submission_mode", "async")
+        }
+        result = self._post("/client/submit", content, headers)
         slugs = "/".join(self._options.get(x) for x in ["team", "suite", "version"])
         for case in self._cases.values():
             testcase_name = case._metadata().get("testcase")
@@ -411,6 +419,7 @@ class Client:
                         f"/client/submit/artifact/{slugs}/{testcase_name}/{key}",
                         value.val._value.binary(),
                     )
+        return result
 
     def seal(self):
         """
@@ -429,10 +438,10 @@ class Client:
             with the Touca server.
         """
         if not self._configured or self._options.get("offline"):
-            raise ToucaError("client_not_configured")
+            raise ToucaError("capture_not_configured")
         slugs = "/".join(self._options.get(x) for x in ["team", "suite", "version"])
-        response = self._transport.request(method="POST", path=f"/batch/{slugs}/seal2")
+        response = self._transport.request(method="POST", path=f"/client/seal/{slugs}")
         if response.status == 403:
             raise ToucaError("auth_invalid_key")
         if response.status != 204:
-            raise ToucaError("seal_failed")
+            raise ToucaError("transport_seal")
