@@ -1,8 +1,6 @@
-#!/usr/bin/env python
-
 # Copyright 2021 Touca, Inc. Subject to Apache-2.0 License.
 
-from ._client import Client
+from touca._client import Client
 
 
 class scoped_timer:
@@ -16,9 +14,7 @@ class scoped_timer:
         self._name = name
 
     def __enter__(self):
-        """ """
         Client.instance().start_timer(self._name)
 
     def __exit__(self, exc_type, exc_value, traceback):
-        """ """
         Client.instance().stop_timer(self._name)
